pub struct ProcessedCheckInResult {
pub routing_hint: Uuid,
pub payload: Vec<u8>,
}Expand description
The result from calling process_check_in
Fields
routing_hint: UuidThe routing key to be used for the check-in payload.
Important to help ensure monitor check-ins are processed in order by routing check-ins from the same monitor to the same place.
payload: Vec<u8>The JSON payload of the processed check-in.